Citing *findiff*
================

You have used *findiff* in a publication? Here is how you can cite it:

    M. Baer. *findiff* software package. URL: https://github.com/maroba/findiff. 2018

BibTeX entry:

.. code-block:: latex

    @misc{findiff,
      title = {{findiff} Software Package},
      author = {M. Baer},
      url = {https://github.com/maroba/findiff},
      key = {findiff},
      note = {\url{https://github.com/maroba/findiff}},
      year = {2018}
    }

